hgext/keyword.py
changeset 13270 1e0d631b843b
parent 13079 f3a2bb1e4255
child 13298 f715e6bd8091
--- a/hgext/keyword.py	Sun Jan 16 19:12:54 2011 +0800
+++ b/hgext/keyword.py	Sun Jan 16 15:45:26 2011 +0100
@@ -70,9 +70,8 @@
 replaced with customized keywords and templates. Again, run
 :hg:`kwdemo` to control the results of your configuration changes.
 
-Before changing/disabling active keywords, run :hg:`kwshrink` to avoid
-the risk of inadvertently storing expanded keywords in the change
-history.
+Before changing/disabling active keywords, you must run :hg:`kwshrink`
+to avoid storing expanded keywords in the change history.
 
 To force expansion after enabling it, or a configuration change, run
 :hg:`kwexpand`.
@@ -465,8 +464,7 @@
 def shrink(ui, repo, *pats, **opts):
     '''revert expanded keywords in the working directory
 
     Run before changing/disabling active keywords or if you experience
     problems with :hg:`import` or :hg:`merge`.
 
     kwshrink refuses to run if given files contain local changes.
     '''
@@ -465,8 +464,7 @@
     '''revert expanded keywords in the working directory
 
-    Run before changing/disabling active keywords or if you experience
-    problems with :hg:`import` or :hg:`merge`.
+    Must be run before changing/disabling active keywords.
 
     kwshrink refuses to run if given files contain local changes.